// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <StepVisual_CurveStyle.hxx>
#include <StepVisual_SurfaceStyleSegmentationCurve.hxx>

IMPLEMENT_STANDARD_RTTIEXT(StepVisual_SurfaceStyleSegmentationCurve, Standard_Transient)

StepVisual_SurfaceStyleSegmentationCurve::StepVisual_SurfaceStyleSegmentationCurve() {}

void StepVisual_SurfaceStyleSegmentationCurve::Init(
  const Handle(StepVisual_CurveStyle)& aStyleOfSegmentationCurve)
{
  // --- classe own fields ---
  styleOfSegmentationCurve = aStyleOfSegmentationCurve;
}

void StepVisual_SurfaceStyleSegmentationCurve::SetStyleOfSegmentationCurve(
  const Handle(StepVisual_CurveStyle)& aStyleOfSegmentationCurve)
{
  styleOfSegmentationCurve = aStyleOfSegmentationCurve;
}

Handle(StepVisual_CurveStyle) StepVisual_SurfaceStyleSegmentationCurve::StyleOfSegmentationCurve()
  const
{
  return styleOfSegmentationCurve;
}
